"""Version information for the flavors2 package.

This file defines the ``__version__`` attribute, which follows semantic
versioning. Update the version string whenever you make a release.
"""

__version__ = "0.1.0"
